@@ -5,7 +5,7 @@
 
     The Anti-Lamenessing Engine is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
     The Anti-Lamenessing Engine is distributed in the hope that it will be useful,
@@ -21,10 +21,39 @@
 #ifndef __ale_accum_h__
 #define __ale_accum_h__
 
+#include "ale_fixed.h"
+
+#define FIXED16 4
+#define FIXED32 5
+
 /*
  * Real-valued type used when accumulating over the domain of an image.
  */
 
+#if ALE_COLORS == FIXED16
+
+typedef ale_fixed<ale_fixed_16_accum,12> ale_accum;
+
+#define ale_accum_enable_casting() ale_accum::enable_casting()
+#define ale_accum_disable_casting() ale_accum::disable_casting()
+
+#elif ALE_COLORS == FIXED32
+
+typedef ale_fixed<ale_fixed_32_accum,15> ale_accum;
+
+#define ale_accum_enable_casting() ale_accum::enable_casting()
+#define ale_accum_disable_casting() ale_accum::disable_casting()
+
+#else
+
 typedef double ale_accum;
 
+#define ale_accum_disable_casting()
+#define ale_accum_enable_casting()
+
+#endif
+
+#undef FIXED32
+#undef FIXED16
+
 #endif
