@@ -27,8 +27,10 @@
 
 namespace d2 {
 	#include "d2/align.cc"
+	#include "d2/trans_multi.cc"
 	#include "d2/render.cc"
 	#include "d2/image_rw.cc"
+	#include "d2/image.cc"
 	#include "d2/exposure/exposure.cc"
 	#include "d2/vise_core.cc"
 	#include "d2/tfile.cc"
