@@ -5,7 +5,7 @@
 
     The Anti-Lamenessing Engine is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
     The Anti-Lamenessing Engine is distributed in the hope that it will be useful,
@@ -26,25 +26,27 @@
 
 #include <stdint.h>
 #include <assert.h>
-#include <math.h>
+// #include <math.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
 #include <limits.h>
 
 #include <vector>
+#include <stack>
 #include <algorithm>
 
+#include <iostream>
+#include <ostream>
+#include <typeinfo>
+
+#include "ale_math.h"
 #include "ale_real.h"
 #include "ale_accum.h"
 #include "ale_pos.h"
 #include "ui/ui.h"
 
 
-#include <iostream>
-#include <ostream>
-#include <typeinfo>
-
 #ifdef USE_MAGICK
 #include <magick/api.h>
 
@@ -75,10 +77,7 @@
 #define M_PI 3.14159265358979323846
 #endif
 
-#ifdef USE_PTHREAD
-#include <pthread.h>
 #include "thread.h"
-#endif
 
 #include "rand.h"
 
