@@ -5,7 +5,7 @@
 
     The Anti-Lamenessing Engine is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
     The Anti-Lamenessing Engine is distributed in the hope that it will be useful,
@@ -20,5 +20,5 @@
 
 #include "exposure.h"
 
-float exposure::confidence_exponent = 0.0;
+ale_real exposure::confidence_exponent = (ale_real) 1.0;
 ale_real exposure::_gain_reference = 1;
