@@ -5,7 +5,7 @@
 
     The Anti-Lamenessing Engine is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
     The Anti-Lamenessing Engine is distributed in the hope that it will be useful,
@@ -36,24 +36,25 @@
 
 class exposure {
 private:
-	static float confidence_exponent;
+	static ale_real confidence_exponent;
 	pixel _multiplier;
 	ale_real _gain_multiplier;
 	static ale_real _gain_reference;
+	ale_real _black_level;
 
 public:
 
 	/*
 	 * confidence/uniform static mutators
 	 */
-	static void set_confidence(float exponent) {
+	static void set_confidence(ale_real exponent) {
 		confidence_exponent = exponent;
 	}
 
 	/*
 	 * confidence accessor
 	 */
-	static float get_confidence() {
+	static ale_real get_confidence() {
 		return confidence_exponent;
 	}
 
@@ -65,7 +66,7 @@ public:
 		friend class exposure;
 	private:
 		listener *next;
-		char *name;
+		const char *name;
 		const exposure *target;
 	public:
 		virtual void trigger(pixel multiplier) = 0;
@@ -86,7 +87,7 @@ private:
 	mutable listener *listener_head;
 public:
 
-	void add_listener(listener *l, char *name) const {
+	void add_listener(listener *l, const char *name) const {
 	
 		/*
 		 * This is a metafunction, so we consider it
@@ -128,7 +129,6 @@ public:
 		listener *cl = listener_head;
 
 		while(cl != NULL) {
-			// fprintf(stderr, "Triggering '%s'.\n", cl->name);
 			cl->trigger(_multiplier / this->_multiplier);
 			cl = cl->next;
 		}
@@ -144,6 +144,14 @@ public:
 		return _gain_multiplier;
 	}
 
+	void set_black_level(ale_real b) {
+		_black_level = b;
+	}
+
+	ale_real get_black_level() {
+		return _black_level;
+	}
+
 	static void set_gain_reference(ale_real r) {
 		_gain_reference = r;
 	}
@@ -157,21 +165,38 @@ public:
 	}
 
 	virtual ale_real confidence(unsigned int k, ale_real input, 
-			ale_real confidence_floor = 0.001) const {
+			ale_real confidence_floor = ale_real_confidence_floor) const {
 
-		if (confidence_exponent == 0)
+		ale_real _0 = (ale_real) 0;
+		ale_real _4 = (ale_real) 4;
+		ale_real _2 = (ale_real) 2;
+		ale_real _1 = (ale_real) 1;
+
+		if (confidence_exponent == _0)
 			return 1;
 
 		ale_real input_scaled = input / _multiplier[k];
 
-		ale_real unexponentiated = 4 * (0.25 - pow(0.5 - input_scaled, 2));
+		ale_real unexponentiated = _1 - _4 * ((_1 / _2) - input_scaled)
+		                                   * ((_1 / _2) - input_scaled);
+
+// 		ale_real unexponentiated = _4 * ((_1 / _4) - (ale_real) ((_1 / _2) - input_scaled)
+// 		                                                      * ((_1 / _2) - input_scaled));
+
 		// ale_real unexponentiated = 4 * input_scaled * (0.25 - pow(0.5 - input_scaled, 2));
 
-		if (unexponentiated < 0) 
-			return confidence_floor;
+		ale_real exponentiated;
 
-		ale_real exponentiated =  pow(unexponentiated, 
-				              confidence_exponent);
+		if (confidence_exponent != _1) {
+
+			if (unexponentiated < _0) 
+				return confidence_floor;
+
+			exponentiated = pow(unexponentiated, confidence_exponent);
+
+		} else {
+			exponentiated = unexponentiated;
+		}
 
 		if (exponentiated < confidence_floor || !finite(exponentiated))
 			return confidence_floor;
@@ -184,9 +209,9 @@ public:
 	 * extremes of camera response and maximal at the center.
 	 */
 	virtual pixel confidence(pixel input, 
-			ale_real confidence_floor = 0.001) const {
+			ale_real confidence_floor = ale_real_confidence_floor) const {
 
-		if (confidence_exponent) {
+		if (confidence_exponent != 0) {
 			return pixel(confidence(0, input[0], confidence_floor),
 				     confidence(1, input[1], confidence_floor),
 				     confidence(2, input[2], confidence_floor));
@@ -204,10 +229,10 @@ public:
 	 * 'upper_one_sided_confidence' instead?
 	 */
 	virtual pixel one_sided_confidence(pixel input, pixel sign) const {
-		if (confidence_exponent) {
+		if (confidence_exponent != 0) {
 			pixel result = confidence(input);
 			for (unsigned int k = 0; k < 3; k++) {
-				if (sign[k] > 0 && input[k] / _multiplier[k] > 0.5)
+				if (sign[k] > 0 && input[k] / _multiplier[k] > 1 / (ale_real) 2)
 					result[k] = 1;
 			}
 			return result;
@@ -223,6 +248,7 @@ public:
 		listener_head = NULL;
 		_multiplier = pixel(1, 1, 1);
 		_gain_multiplier = 1;
+		_black_level = 0;
 	}
 
 	virtual ~exposure() {
