@@ -52,8 +52,8 @@ private:
 	 * It might be better to localize elements having identical spatial
 	 * coordinates.
 	 */
-	image_ale_real **colors;
-	image_ale_real **weights;
+	image **colors;
+	image **weights;
 	unsigned int capacity;
 
 public:
@@ -68,8 +68,8 @@ public:
 		} else
 			assert(0);
 
-		colors  = (image_ale_real **) malloc(this->capacity * sizeof(image_ale_real *));
-		weights = (image_ale_real **) malloc(this->capacity * sizeof(image_ale_real *));
+		colors  = (image **) malloc(this->capacity * sizeof(image *));
+		weights = (image **) malloc(this->capacity * sizeof(image *));
 
 		assert(colors);
 		assert(weights);
@@ -80,8 +80,8 @@ public:
 		}
 
 		for (unsigned int f = 0; f < this->capacity; f++) {
-			colors[f] = new image_ale_real(dimy, dimx, depth);
-			weights[f] = new image_ale_real(dimy, dimx, depth);
+			colors[f] = new_image_ale_real(dimy, dimx, depth);
+			weights[f] = new_image_ale_real(dimy, dimx, depth);
 
 			assert(colors[f]);
 			assert(weights[f]);
@@ -108,16 +108,18 @@ public:
 	 * initializing the new image areas with black pixels.  Negative values
 	 * shrink the image.
 	 */
-	void extend(int top, int bottom, int left, int right) {
+	image *_extend(int top, int bottom, int left, int right) {
 
 		for (unsigned int f = 0; f < capacity; f++) {
-			colors[f]->extend(top, bottom, left, right);
-			weights[f]->extend(top, bottom, left, right);
+			extend(&colors[f], top, bottom, left, right);
+			extend(&weights[f], top, bottom, left, right);
 		}
 
 		_dimx = colors[0]->width();
 		_dimy = colors[0]->height();
 		_offset = colors[0]->offset();
+
+		return NULL;
 	}
 
 	int accumulate_norender(int i, int j) {
@@ -143,7 +145,7 @@ public:
 			 */
 			if (f == 0)
 			for (unsigned int ff = 0; ff < capacity; ff++)
-				weights[ff]->pix(i, j)[k] = 0;
+				weights[ff]->set_chan(i, j, k, 0);
 
 			assert (finite(new_weight[k]));
 
@@ -153,31 +155,36 @@ public:
 			for (unsigned int ff = 0; ff < capacity; ff++) {
 				assert (ff <= (unsigned int) f);
 				if (ff == capacity - 1) {
-					colors[ff]->pix(i, j)[k] = new_value[k];
-					weights[ff]->pix(i, j)[k] += new_weight[k];
+					colors[ff]->set_chan(i, j, k, new_value[k]);
+					weights[ff]->set_chan(i, j, k, 
+						weights[ff]->get_chan(i, j, k) + new_weight[k]);
 					break;
 				}
-				if ((ff == 0 && weights[ff]->pix(i, j)[k] == 0)
-				 || (ff >  0 && weights[ff]->pix(i, j)[k] == weights[ff - 1]->pix(i, j)[k])) {
-					colors[ff]->pix(i, j)[k] = new_value[k];
+				if ((ff == 0 && weights[ff]->get_chan(i, j, k) == 0)
+				 || (ff >  0 && weights[ff]->get_chan(i, j, k) == weights[ff - 1]->get_chan(i, j, k))) {
+					colors[ff]->set_chan(i, j, k, new_value[k]);
 					for (unsigned int fff = ff; fff < capacity; fff++)
-						weights[fff]->pix(i, j)[k] += new_weight[k];
+						weights[fff]->set_chan(i, j, k, 
+							weights[fff]->get_chan(i, j, k) + new_weight[k]);
 					break;
 				}
-				if (colors[ff]->pix(i, j)[k] == (ale_sreal) new_value[k]) {
+				if (colors[ff]->get_chan(i, j, k) == (ale_sreal) new_value[k]) {
 					for (unsigned int fff = ff; fff < capacity; fff++)
-						weights[fff]->pix(i, j)[k] += new_weight[k];
+						weights[fff]->set_chan(i, j, k, 
+							weights[fff]->get_chan(i, j, k) + new_weight[k]);
 					break;
 				}
-				if (colors[ff]->pix(i, j)[k] > (ale_sreal) new_value[k]) {
+				if (colors[ff]->get_chan(i, j, k) > (ale_sreal) new_value[k]) {
 					for (unsigned int fff = capacity - 1; fff > ff; fff--) {
-						weights[fff]->pix(i, j)[k] = weights[fff - 1]->get_pixel(i, j)[k] + new_weight[k];
-						colors[fff]->pix(i, j)[k]  = colors[fff - 1]->pix(i, j)[k];
+						weights[fff]->set_chan(i, j, k,  weights[fff - 1]->get_pixel(i, j)[k] + new_weight[k]);
+						colors[fff]->set_chan(i, j, k, colors[fff - 1]->get_pixel(i, j)[k]);
 					}
-					colors[ff]->pix(i, j)[k] = new_value[k];
-					weights[ff]->pix(i, j)[k] = new_weight[k];
+					colors[ff]->set_chan(i, j, k, new_value[k]);
+					weights[ff]->set_chan(i, j, k, new_weight[k]);
 					if (ff > 0)
-						weights[ff]->pix(i, j)[k] += weights[ff - 1]->pix(i, j)[k];
+						weights[ff]->set_chan(i, j, k,
+							weights[ff]->get_chan(i, j, k)
+						      + weights[ff - 1]->get_chan(i, j, k));
 
 					break;
 				}
@@ -188,11 +195,11 @@ public:
 	/*
 	 * XXX: This is inefficient in cases where only one channel is desired.
 	 */
-	pixel get_pixel(unsigned int y, unsigned int x) const {
+	spixel get_pixel(unsigned int y, unsigned int x) const {
 		pixel result;
 
 		for (int k = 0; k < 3; k++) {
-			ale_real midpoint = weights[capacity - 1]->chan(y, x, k) / 2;
+			ale_real midpoint = weights[capacity - 1]->get_chan(y, x, k) / 2;
 
 			if (midpoint == 0)
 				return pixel::zero();
@@ -206,20 +213,20 @@ public:
 			unsigned int m = h / 2;
 
 			while (h > l + 1) {
-				if ((ale_real) weights[m]->chan(y, x, k) < midpoint)
+				if ((ale_real) weights[m]->get_chan(y, x, k) < midpoint)
 					l = m;
 				else
 					h = m;
 				m = (h + l) / 2;
 			}
 
-			if ((ale_real) weights[l]->chan(y, x, k) < midpoint)
+			if ((ale_real) weights[l]->get_chan(y, x, k) < midpoint)
 				l = h;
-			if ((ale_real) weights[l]->chan(y, x, k) > midpoint)
-				result[k] = colors[l]->chan(y, x, k);
-			else if ((ale_real) weights[l]->chan(y, x, k) == midpoint)
-				result[k] = (colors[l]->chan(y, x, k)
-					   + colors[l + 1]->chan(y, x, k)) / 2;
+			if ((ale_real) weights[l]->get_chan(y, x, k) > midpoint)
+				result[k] = colors[l]->get_chan(y, x, k);
+			else if ((ale_real) weights[l]->get_chan(y, x, k) == midpoint)
+				result[k] = (colors[l]->get_chan(y, x, k)
+					   + colors[l + 1]->get_chan(y, x, k)) / 2;
 			else
 				assert(0);
 			
