@@ -5,7 +5,7 @@
 
     The Anti-Lamenessing Engine is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
     The Anti-Lamenessing Engine is distributed in the hope that it will be useful,
@@ -42,6 +42,21 @@ public:
 		x[2] = x2;
 	}
 
+	pixel(const pixel &p) {
+		x[0] = p[0];
+		x[1] = p[1];
+		x[2] = p[2];
+	}
+
+	pixel &operator=(const pixel &p) {
+		x[0] = p[0];
+		x[1] = p[1];
+		x[2] = p[2];
+
+		return (*this);
+	}
+
+
 //	Due to automatic typecasts and automatic int <==> ale_real *
 //	conversions, this can cause some really weird bugs.
 //
@@ -51,17 +66,23 @@ public:
 //		x[2] = _x[2];
 //	}
 
-	const ale_real &operator[](int i) const {
-		assert (i >= 0);
+	const ale_real &operator[](unsigned int i) const {
+#if 0
+		/*
+		 * This may be expensive.
+		 */
 		assert (i < 3);
-
+#endif
 		return x[i];
 	}
 
-	ale_real &operator[](int i) {
-		assert (i >= 0);
+	ale_real &operator[](unsigned int i) {
+#if 0
+		/*
+		 * This may be expensive.
+		 */
 		assert (i < 3);
-
+#endif
 		return x[i];
 	}
 
@@ -85,7 +106,7 @@ public:
 		return pixel(x[0] / d, x[1] / d, x[2] / d);
 	}
 
-	pixel operator*(pixel p) const {
+	pixel mult(pixel p) const {
 		return pixel(x[0] * p[0], x[1] * p[1], x[2] * p[2]);
 	}
 
@@ -164,7 +185,7 @@ public:
 		return m;
 	}
 
-	ale_real min_norm() {
+	ale_real min_norm() const {
 		ale_real m = x[0];
 		if (x[1] < m)
 			m = x[1];
@@ -188,6 +209,10 @@ public:
 		return pixel(0, 0, 0);
 	}
 
+	static pixel one() {
+		return pixel(1, 1, 1);
+	}
+
 	int operator==(const pixel &p) {
 		return x[0] == p[0]
 		    && x[1] == p[1]
@@ -209,36 +234,30 @@ public:
 	}
 };
 
-inline pixel operator*(const pixel &p, float d) {
+inline pixel operator*(const pixel &p, const pixel &q) {
+	return p.mult(q);
+}
+
+template<typename T>
+inline pixel operator*(T d, const pixel &p) {
 	return p.mult(d);
 }
-inline pixel operator*(const pixel &p, double d) {
-	return p.mult(d);
-}
-inline pixel operator*(double d, const pixel &p) {
-	return p.mult(d);
-}
-inline pixel operator*(float d, const pixel &p) {
+template<typename T>
+inline pixel operator*(const pixel &p, T d) {
 	return p.mult(d);
 }
 
 inline std::ostream &operator<<(std::ostream &o, const pixel &p) {
-	o << "[" << p[0] << " " << p[1] << " " << p[2] << "]";
+	o << "[" << (double) p[0] << " " << (double) p[1] << " " << (double) p[2] << "]";
 	return o;
 }
 
-inline pixel ppow(pixel p, double d) {
+template<typename T>
+inline pixel ppow(pixel p, T d) {
 	return pixel(
-			pow((double) p[0], d),
-			pow((double) p[1], d),
-			pow((double) p[2], d));
-}
-
-inline pixel ppow(pixel p, float d) {
-	return pixel(
-			pow((double) p[0], d),
-			pow((double) p[1], d),
-			pow((double) p[2], d));
+			pow(p[0], d),
+			pow(p[1], d),
+			pow(p[2], d));
 }
 
 inline pixel pexp(pixel p) {
@@ -248,4 +267,11 @@ inline pixel pexp(pixel p) {
 			exp((double) p[2]));
 }
 
+inline pixel psqrt(pixel p) {
+	return pixel(
+			sqrt(p[0]),
+			sqrt(p[1]),
+			sqrt(p[2]));
+}
+
 #endif
