@@ -5,7 +5,7 @@
 
     The Anti-Lamenessing Engine is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
     The Anti-Lamenessing Engine is distributed in the hope that it will be useful,
@@ -38,16 +38,24 @@ public:
 		x[1] = x1;
 	}
 
-	const ale_pos &operator[](int i) const {
-		assert (i >= 0);
+	const ale_pos &operator[](unsigned int i) const {
+#if 0
+		/*
+		 * This may be expensive.
+		 */
 		assert (i < 2);
+#endif
 
 		return x[i];
 	}
 
-	ale_pos &operator[](int i) {
-		assert (i >= 0);
+	ale_pos &operator[](unsigned int i) {
+#if 0
+		/*
+		 * This may be expensive.
+		 */
 		assert (i < 2);
+#endif
 
 		return x[i];
 	}
@@ -76,7 +84,7 @@ public:
 		return *this;
 	}
 
-	point mult(ale_real d) const {
+	point mult(ale_pos d) const {
 		return point(x[0] * d, x[1] * d);
 	}
 
@@ -87,12 +95,12 @@ public:
 		return point(x[0] * p[0], x[1] * p[1]);
 	}
 	
-	point operator *=(ale_real d) {
+	point operator *=(ale_pos d) {
 		(*this) = mult(d);
 		return *this;
 	}
 
-	point operator/(ale_real d) const {
+	point operator/(ale_pos d) const {
 		return point(x[0] / d, x[1] / d);
 	}
 
@@ -135,15 +143,15 @@ public:
 		ale_pos to_p = lengthtosq(p);
 		ale_pos to_q = lengthtosq(q);
 
-		ale_pos cos_of = (to_p + to_q - p.lengthtosq(q))
+		ale_pos cos_of = (double) (to_p + to_q - p.lengthtosq(q))
 			       / (2 * sqrt(to_p) * sqrt(to_q));
 
 		return acos(cos_of);
 	}
 
 	static point posinf() {
-		double a = +1;
-		double z = +0;
+		ale_pos a = +1;
+		ale_pos z = +0;
 
 		a = a / z;
 
@@ -193,7 +201,6 @@ public:
 	static int defined(const point &p) {
 		return p.defined();
 	}
-
 };
 
 inline point operator*(const point &p, double d) {
