@@ -5,7 +5,7 @@
 
     The Anti-Lamenessing Engine is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
     The Anti-Lamenessing Engine is distributed in the hope that it will be useful,
@@ -30,5 +30,5 @@ int render::rx_show;
 render *render::directory[ACTIVE_RENDERER_COUNT];
 int render::directory_length;
 int render::extend;
-double render::scale_factor;
-double render::wt = 0.0001;
+ale_pos render::scale_factor;
+ale_real render::wt = 1 / (ale_real) 10000;
