@@ -111,6 +111,7 @@ protected:
         int synced;
 	int inc;
         image *approximation;
+	image *definition;
         render *input;
         unsigned int iterations;
 	psf *lresponse, *nlresponse;
@@ -136,6 +137,9 @@ protected:
 		const raster *nlresponse;
 		const exposure *exp;
 		point *extents;
+
+		sim_args() : t(transformation::eu_identity()) {
+		}
 	};
 
 	class simulate_linear : public thread::decompose_domain, 
@@ -211,6 +215,8 @@ protected:
 				int jmin = (int) floor(lef + (ale_pos) lresponse->min_j());
 				int jmax = (int) ceil(rig + (ale_pos) lresponse->max_j());
 
+				pixel tr = pixel(1, 1, 1) / t.get_tonal_multiplier(p);
+
 				for (int ii = imin; ii <= imax; ii++)
 				for (int jj = jmin; jj <= jmax; jj++) {
 
@@ -238,16 +244,16 @@ protected:
 					lock();
 
 					if (lsimulated->get_bayer() == IMAGE_BAYER_NONE) {
-						lsimulated->pix(ii, jj) +=
-							r(approximation->pix(i, j));
-						lsim_weights->pix(ii, jj) +=
-							r.weight();
+						lsimulated->add_pixel(ii, jj, 
+							r(approximation->get_pixel(i, j) * tr));
+						lsim_weights->add_pixel(ii, jj,
+							r.weight());
 					} else {
-						int k = ((image_bayer_ale_real *)lsimulated)->bayer_color(ii, jj);
-						lsimulated->chan(ii, jj, k) +=
-							r(approximation->pix(i, j))[k];
-						lsim_weights->chan(ii, jj, k) +=
-							r.weight()[k];
+						int k = lsimulated->bayer_color(ii, jj);
+						lsimulated->add_chan(ii, jj, k,
+							r(approximation->get_pixel(i, j))[k] * tr[k]);
+						lsim_weights->add_chan(ii, jj, k,
+							r.weight()[k]);
 					}
 
 					unlock();
@@ -355,10 +361,10 @@ protected:
 
 					lock();
 
-					nlsimulated->pix(ii, jj) +=
-						r(exp->unlinearize(lsimulated->get_pixel(i, j)));
-					nlsim_weights->pix(ii, jj) +=
-						r.weight();
+					nlsimulated->add_pixel(ii, jj,
+						r(exp->unlinearize(lsimulated->get_pixel(i, j))));
+					nlsim_weights->add_pixel(ii, jj,
+						r.weight());
 
 					unlock();
 				}
@@ -406,12 +412,12 @@ protected:
 		image *lsim_weights = NULL;
 
 		if (lsimulated->get_bayer() == IMAGE_BAYER_NONE) {
-			lsim_weights = new image_ale_real(
+			lsim_weights = new_image_ale_real(
 				lsimulated->height(),
 				lsimulated->width(),
 				lsimulated->depth());
 		} else {
-			lsim_weights = new image_bayer_ale_real(
+			lsim_weights = new_image_bayer_ale_real(
 				lsimulated->height(),
 				lsimulated->width(),
 				lsimulated->depth(), 
@@ -450,13 +456,14 @@ protected:
 				if ((lsimulated->get_channels(ii, jj) & (1 << k)) == 0)
 					continue;
 
-				ale_real weight = lsim_weights->chan(ii, jj, k);
+				ale_real weight = lsim_weights->get_chan(ii, jj, k);
 
 				if (!(weight > weight_floor))
-					lsimulated->chan(ii, jj, k)
-						/= zero;  /* Generate a non-finite value */
+					lsimulated->div_chan(ii, jj, k, 
+						zero);  /* Generate a non-finite value */
 				else
-					lsimulated->chan(ii, jj, k) /= weight;
+					lsimulated->div_chan(ii, jj, k,
+						weight);
 			}
 		}
 
@@ -478,7 +485,7 @@ protected:
 		 * Initialize non-linear
 		 */
 
-		image_ale_real *nlsim_weights = new image_ale_real(
+		image *nlsim_weights = new_image_ale_real(
 				nlsimulated->height(),
 				nlsimulated->width(),
 				nlsimulated->depth());
@@ -504,11 +511,10 @@ protected:
 
 			for (int k = 0; k < 3; k++)
 				if (!(weight[k] > weight_floor))
-					nlsimulated->pix(ii, jj)[k]
-						/= zero;  /* Generate a non-finite value */
+					nlsimulated->div_chan(ii, jj, k,
+						zero);  /* Generate a non-finite value */
 
-			nlsimulated->pix(ii, jj)
-				/= weight;
+			nlsimulated->div_pixel(ii, jj, weight);
 		}
 
 		/*
@@ -548,8 +554,8 @@ protected:
 			if (use_weighted_median)
 				iwm = new image_weighted_median(h, w, d);
 			this->weight_limit = weight_limit;
-			c = new image_ale_real(h, w, d);
-			cc = new image_ale_real(h, w, d);
+			c = new_image_ale_real(h, w, d);
+			cc = new_image_ale_real(h, w, d);
 		}
 
 		/*
@@ -592,8 +598,8 @@ protected:
 			if (use_weighted_median)
 				return iwm->get_colors()->get_pixel(i, j);
 			else
-				return c->get_pixel(i, j)
-				     / cc->get_pixel(i, j);
+				return (pixel) c->get_pixel(i, j)
+				     / (pixel) cc->get_pixel(i, j);
 		}
 
 		/*
@@ -615,8 +621,8 @@ protected:
 					/*
 					 * Reset the counters
 					 */
-					c->pix(i, j) = pixel::zero();
-					cc->pix(i, j) = pixel::zero();
+					c->set_pixel(i, j, pixel::zero());
+					cc->set_pixel(i, j, pixel::zero());
 				}
 			}
 		}
@@ -626,8 +632,8 @@ protected:
 		 * a weighted median update.
 		 */
 		void update(int i, int j, pixel value_times_weight, pixel weight) {
-			c->pix(i, j) += value_times_weight;
-			cc->pix(i, j) += weight;
+			c->add_pixel(i, j, value_times_weight);
+			cc->add_pixel(i, j, weight);
 		}
 	};
 
@@ -661,6 +667,9 @@ protected:
 		const backprojector *lresponse;
 		const backprojector *nlresponse;
 		double weight_limit;
+
+		correct_args() : t(transformation::eu_identity()) {
+		}
 	};
 
 	class correct_nonlinear : public thread::decompose_domain, 
@@ -748,7 +757,7 @@ protected:
 					 * Error calculation
 					 */
 
-					lreal->pix(i, j) += bpv;
+					lreal->add_pixel(i, j, bpv);
 				}
 			}
 
@@ -825,6 +834,8 @@ protected:
 				int jmin = (int) floor(lef + (ale_pos) lresponse->min_j());
 				int jmax = (int) ceil(rig + (ale_pos) lresponse->max_j());
 
+				pixel tr = t.get_tonal_multiplier(p);
+
 				for (int ii = imin; ii <= imax; ii++)
 				for (int jj = jmin; jj <= jmax; jj++) {
 
@@ -901,7 +912,7 @@ protected:
 					 * for confidence.
 					 */
 
-					pixel bpv = r(comp_lreal - comp_simu);
+					pixel bpv = tr * r(comp_lreal - comp_simu);
 
 					/*
 					 * Confidence [equal to (1, 1, 1) when
@@ -930,7 +941,7 @@ protected:
 					 */
 
 					if (real->get_bayer() != IMAGE_BAYER_NONE) {
-						int color = ((image_bayer_ale_real *)real)->bayer_color(ii, jj);
+						int color = real->bayer_color(ii, jj);
 						conf[(color + 1) % 3] = 0;
 						conf[(color + 2) % 3] = 0;
 					}
@@ -991,7 +1002,7 @@ protected:
 			lreal = real;
 		else {
 
-			image *new_lreal = new image_ale_real(
+			image *new_lreal = new_image_ale_real(
 					real->height(),
 					real->width(),
 					real->depth(),
@@ -1051,9 +1062,9 @@ protected:
 			                  j < (unsigned int)  ceil(extents[1][1]); j++) {
 
 				if (real->get_bayer() != IMAGE_BAYER_NONE) {
-					int color = ((image_bayer_ale_real *)real)->bayer_color(i, j);
-					ale_real s = lsimulated->chan(i, j, color);
-					ale_real r = lreal->chan(i, j, color);
+					int color = real->bayer_color(i, j);
+					ale_real s = lsimulated->get_chan(i, j, color);
+					ale_real r = lreal->get_chan(i, j, color);
 
 					if (!finite(s)
 					 || !finite(r))
@@ -1123,12 +1134,12 @@ protected:
                 image *lsimulated;
 		
 		if (real->get_bayer() == IMAGE_BAYER_NONE) {
-			lsimulated = new image_ale_real(
+			lsimulated = new_image_ale_real(
 				real->height(),
 				real->width(), 
 				real->depth());
 		} else {
-			lsimulated = new image_bayer_ale_real(
+			lsimulated = new_image_bayer_ale_real(
 				real->height(),
 				real->width(),
 				real->depth(),
@@ -1138,7 +1149,7 @@ protected:
                 image *nlsimulated = NULL;
 
 		if (nlf)
-			nlsimulated = new image_ale_real(
+			nlsimulated = new_image_ale_real(
 				real->height(),
 				real->width(), 
 				real->depth());
@@ -1278,7 +1289,7 @@ protected:
 					if (new_value < 0)
 						new_value = 0;
 
-					approximation->chan(i, j, k) = new_value;
+					approximation->set_chan(i, j, k, new_value);
 				}
 			}
 
@@ -1333,7 +1344,11 @@ public:
         }
 
         const image *get_defined() const {
-                return input->get_defined();
+		if (synced) {
+			assert(0);  /* definition is not set */
+			return definition;
+		} else
+			return input->get_defined();
         }
 
         void sync(int n) {
@@ -1348,7 +1363,9 @@ public:
         virtual int sync() {
 		input->sync();
                 synced = 1;
-                approximation = optimizations::get_ip_working_image(input->get_image());
+		approximation = input->get_image()->clone("IPC Approximation");
+		// definition = input->get_defined()->clone("IPC Definition");
+		optimizations::ip_sources_obtained(this);
 		ui::get()->ip_start();
                 _ip();
 		ui::get()->ip_done();
