@@ -5,7 +5,7 @@
 
     The Anti-Lamenessing Engine is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
     The Anti-Lamenessing Engine is distributed in the hope that it will be useful,
@@ -130,10 +130,10 @@ public:
 	 * support may include everything up to and including the boundaries
 	 * specified here.
 	 */
-	virtual float min_i() const = 0;
-	virtual float max_i() const = 0;
-	virtual float min_j() const = 0;
-	virtual float max_j() const = 0;
+	virtual ale_real min_i() const = 0;
+	virtual ale_real max_i() const = 0;
+	virtual ale_real min_j() const = 0;
+	virtual ale_real max_j() const = 0;
 
 	/*
 	 * Get the number of varieties supported by this PSF.  These usually
@@ -158,15 +158,21 @@ public:
 	 * based on position (e.g. some sensor arrays stagger red, green, and
 	 * blue sensors).
 	 */
-	virtual psf_result operator()(float top, float bot, float lef, float
+	virtual psf_result operator()(ale_real top, ale_real bot, ale_real lef, ale_real
 			rig, unsigned int variety) const = 0;
 
+	virtual psf_result operator()(ale_real top, ale_real bot, ale_real lef, ale_real
+			rig, unsigned int variety, char channels) const {
+		return operator()(top, bot, lef, rig, variety);
+	}
+
+
 #if 0
 	/*
 	 * Get the average pixel response.  This function should be overloaded
 	 * for PSFs that support multiple varieties.
 	 */
-	virtual psf_result operator()(float top, float bot, float lef, float rig) const {
+	virtual psf_result operator()(ale_real top, ale_real bot, ale_real lef, ale_real rig) const {
 		return operator()(top, bot, lef, rig, 0);
 	}
 #endif
