@@ -5,7 +5,7 @@
 
     The Anti-Lamenessing Engine is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
     The Anti-Lamenessing Engine is distributed in the hope that it will be useful,
@@ -36,6 +36,7 @@ protected:
 	unsigned int _filter_dim_j;
 	unsigned int num_arrays;
 	ale_real **response_arrays;
+	ale_real **response_partials;
 #if 0
 	ale_real *avg_response;
 #endif
@@ -50,21 +51,21 @@ public:
 	 * support may include everything up to and including the boundaries
 	 * specified here.
 	 */
-       inline ale_real min_i() const { return -_height; }
-       inline ale_real max_i() const { return  _height; }
-       inline ale_real min_j() const { return -_width; }
-       inline ale_real max_j() const { return  _width; }
+	ale_real min_i() const { return ale_real_unexceptional_negation(_height); }
+	ale_real max_i() const { return  _height; }
+	ale_real min_j() const { return ale_real_unexceptional_negation(_width); }
+	ale_real max_j() const { return  _width; }
 
 	/*
 	 * Element accessor methods.
 	 */
-       inline unsigned int max_elem_i() {
+	unsigned int max_elem_i() {
 		return _filter_dim_i;
 	}
-       inline unsigned int max_elem_j() {
+	unsigned int max_elem_j() {
 		return _filter_dim_j;
 	}
-       inline ale_real element(unsigned int n, unsigned int i, unsigned int j, unsigned int k) {
+	ale_real element(unsigned int n, unsigned int i, unsigned int j, unsigned int k) {
 
 		assert (n < num_arrays);
 		assert (i < _filter_dim_i);
@@ -74,7 +75,7 @@ public:
 		return response_arrays[n][i * _filter_dim_j * 3 + j * 3 + k];
 	}
 #if 0
-       inline ale_real element(unsigned int i, unsigned int j, unsigned int k) {
+	ale_real element(unsigned int i, unsigned int j, unsigned int k) {
 		assert (i < _filter_dim_i);
 		assert (j < _filter_dim_j);
 		assert (k < 3);
@@ -103,85 +104,73 @@ public:
 	 * specified, then the average response is returned.
 	 */
 private:
-	psf_result generic_response(ale_real *response_array, float top, float
-			bot, float lef, float rig) const {
+	psf_result generic_response(ale_real *response_partial, ale_real top, ale_real
+			bot, ale_real lef, ale_real rig, char channels) const {
 
-		assert (response_array != NULL);
+		assert (response_partial != NULL);
 
 		psf_result result;
-		int il, jl, ih, jh;
 
-		/** precompute a few values **/
-		ale_real range_i = 2 * _height;
-		ale_real range_j = 2 * _width;
-		ale_real premult_i = _filter_dim_i / range_i;
-		ale_real premult_j = _filter_dim_j / range_j;
-
-
-		/** handle the outliers in an intelligent manner **/
-		if (top < -_height) {
-
-			il = 0;
-			top = -_height;
-		}
-		else
-			il = (int) floor( (top + _height) * premult_i );
-
-		if (lef < -_width) {
-			jl = 0;
-			lef = -_width;
-		}
-		else
-			jl = (int) floor( (lef + _width) * premult_j );
-
-		/**   are the funny-looking subtractions needed?  **/
 		/*
-		 *   The -0.001 terms set a lower bound for each dimension, and
-		 *   were added to avoid loss of precision, and hence image
-		 *   artifacts, due to division by small numbers.  An
-		 *   alternative approach could be used instead.
-		 *   	
-		 *       --dhilvert, 03-Feb-2007
-		*/
+		 * lrintf() can be more efficient than floor() or float-to-int
+		 * casts.  For more details, see Erik de Castro Lopo, "Faster
+		 * Floating Point to Integer Conversions":
+		 *
+		 * 	http://mega-nerd.com/FPcast/
+		 *
+		 * In this case, lrintf() seems to be a bit faster than plain
+		 * casting, and much faster than floor(0.5 + ...).  Casting
+		 * from round() seems to be an acceptable alternative to
+		 * lrintf().
+		 *
+		 * Early calculation of common floating-point constants in the
+		 * following code is based on an initial implementation by HJ
+		 * Hornbeck.
+		 */
 
-		if (bot > _height) {
+		ale_real i_element_scale = (ale_real) _filter_dim_i / (max_i() - min_i());
+		ale_real j_element_scale = (ale_real) _filter_dim_j / (max_j() - min_j());
 
-			ih = (int) floor( _filter_dim_i - 0.001 );
-			bot = _height;
-		}
-		else
-			ih = (int) floor( (bot + _height) / range_i * (_filter_dim_i - 0.001) );
-                      
-		if (rig > _width) {
+		int il = (int) lrintf(i_element_scale * (top - min_i()));
+		int ih = (int) lrintf(i_element_scale * (bot - min_i()));
+		int jl = (int) lrintf(j_element_scale * (lef - min_j()));
+		int jh = (int) lrintf(j_element_scale * (rig - min_j()));
 
-			jh = (int) floor( _filter_dim_j - 0.001 );
-			rig = _width;
-		}
-		else
-			jh = (int) floor( (rig + _width) / range_j * (_filter_dim_i - 0.001) );
+		/*
+		 * Bounds clamping may be faster when performed in integer 
+		 * arithmetic than in floating-point, so we do this after 
+		 * float-to-int conversion is complete.
+		 */
 
+		if (il < 0)
+			il = 0;
+		if (jl < 0)
+			jl = 0;
+		if (ih > (int) _filter_dim_i)
+			ih = (int) _filter_dim_i;
+		if (jh > (int) _filter_dim_j)
+			jh = (int) _filter_dim_j;
 
-		for (int ii = il; ii <= ih; ii++)
-		for (int jj = jl; jj <= jh; jj++) {
+		if (!(il < ih) || !(jl < jh))
+			return result;
 
-			float ltop = ((float) ii) / premult_i - _height;
-			float lbot = ((float) ii + 1) / premult_i - _height;
-			float llef = ((float) jj) / premult_j - _width;
-			float lrig = ((float) jj + 1) / premult_j - _width;
+		for (int k = 0; k < 3; k++) {
+			if (!((1 << k) & channels))
+				continue;
+			assert (ih > 0 && jh > 0);
+			assert (ih <= (int) _filter_dim_i);
+			assert (jh <= (int) _filter_dim_j);
 
-			if (ltop < top)
-				ltop = top;
-			if (lbot > bot)
-				lbot = bot;
-			if (llef < lef)
-				llef = lef;
-			if (lrig > rig)
-				lrig = rig;
+			ale_real result_k = 0;
 
-			for (int k = 0; k < 3; k++) {
-				result.matrix(k, k) += (ale_real) ((lbot - ltop) * (lrig - llef)
-					      * response_array[3 * _filter_dim_j * ii + 3 * jj + k]);
-			}
+			if (il > 0 && jl > 0) 
+				result_k += response_partial[k + 3 * (jl - 1) + 3 * _filter_dim_j * (il - 1)];
+			if (il > 0) 
+				result_k -= response_partial[k + 3 * (jh - 1) + 3 * _filter_dim_j * (il - 1)];
+			if (jl > 0)
+				result_k -= response_partial[k + 3 * (jl - 1) + 3 * _filter_dim_j * (ih - 1)];
+			result_k += response_partial[k + 3 * (jh - 1) + 3 * _filter_dim_j * (ih - 1)];
+			result.set_matrix(k, k, result_k);
 		}
 
 		return result;
@@ -195,13 +184,19 @@ public:
 	/*
 	 * Get a specific pixel response.
 	 */
-	psf_result operator()(float top, float bot, float lef, float rig, unsigned int variety) const {
+	psf_result operator()(ale_real top, ale_real bot, ale_real lef, ale_real rig, unsigned int variety, 
+			char channels) const {
 		assert (variety < num_arrays);
 
-		ale_real *response_array = response_arrays[variety];
-		assert (response_array != NULL);
+		ale_real *response_partial = response_partials[variety];
+		assert (response_partial != NULL);
 
-		return generic_response(response_array, top, bot, lef, rig);
+		return generic_response(response_partial, top, bot, lef, rig, channels);
+	}
+
+	psf_result operator()(ale_real top, ale_real bot, ale_real lef, ale_real rig, 
+			unsigned int variety) const {
+		return operator()(top, bot, lef, rig, variety, 0x7);
 	}
 
 #if 0
@@ -226,12 +221,30 @@ protected:
 			result[k] += response_array[i * _filter_dim_j * 3 + j * 3 + k];
 
 		for (unsigned int k = 0; k < 3; k++)
-			result[k] *= (4 * _height * _width)
-				/ (_filter_dim_i * _filter_dim_j);
+			result[k] *= (((ale_real) 4 * _height * _width)
+				/ (ale_real) (_filter_dim_i * _filter_dim_j));
 
 		return result;
 	}
 
+	void partial_integrate(ale_real *target, ale_real *source) {
+		ale_real element_area = (ale_real) (max_i() - min_i())
+		                      * (ale_real) (max_j() - min_j())
+				      / (ale_real) (_filter_dim_i)
+				      / (ale_real) (_filter_dim_j);
+
+		for (unsigned int i = 0; i < _filter_dim_i; i++)
+		for (unsigned int j = 0; j < _filter_dim_j; j++)
+		for (unsigned int k = 0; k < 3            ; k++) {
+			unsigned int index = i * _filter_dim_j * 3 + j * 3 + k;
+			target[index] = source[index] * element_area
+			              + ((j > 0) ? target[index - 3] : ale_real_0)
+				      + ((i > 0) ? target[index - _filter_dim_j * 3] : ale_real_0)
+				      - ((i > 0 
+				       && j > 0) ? target[index - _filter_dim_j * 3 - 3] : ale_real_0);
+		}
+	}
+
 	/*
 	 * Compute integrals.
 	 */
@@ -244,6 +257,16 @@ protected:
 #if 0
 		avg_integral = integrate(avg_response);
 #endif
+
+		response_partials = (ale_real **) malloc(sizeof(ale_real *) * num_arrays);
+		assert(response_partials);
+		for (unsigned int n = 0; n < num_arrays; n++) {
+			response_partials[n] = (ale_real *) malloc(sizeof(ale_real) * _filter_dim_i 
+										    * _filter_dim_j
+										    * 3);
+			assert(response_partials[n]);
+			partial_integrate(response_partials[n], response_arrays[n]);
+		}
 	}
 
 public:
