@@ -5,7 +5,7 @@
 
     The Anti-Lamenessing Engine is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
     The Anti-Lamenessing Engine is distributed in the hope that it will be useful,
@@ -43,7 +43,7 @@ private:
 		exit(1);
 	}
 
-	static void syntax_error(char *explanation) {
+	static void syntax_error(const char *explanation) {
 		fprintf(stderr, "\n\n*** Error: Render syntax: %s ***\n\n", explanation);
 		exit(1);
 	}
@@ -116,6 +116,8 @@ public:
 			return new filter::scaled_filter(get_SF(type + strlen("coarse:")), 1);
 		} else if (!strpfix("fine:", type)) {
 			return new filter::scaled_filter(get_SF(type + strlen("fine:")), 0);
+		} else if (!strpfix("auto:", type)) {
+			return new filter::scaled_filter(get_SF(type + strlen("auto:")), 2);
 		} else {
 			return new filter::scaled_filter(get_SF(type), 1);
 		}
