@@ -5,7 +5,7 @@
 
     The Anti-Lamenessing Engine is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
     The Anti-Lamenessing Engine is distributed in the hope that it will be useful,
@@ -121,10 +121,10 @@ class align {
 		 * 	desired_w_angle = 2 * arctan(w / (2 * sqrt(D*D + h*h/4)))
 		 */
 
-		ale_pos D = sqrt(h * h + w * w)
-			         / (2 * tan(_init_angle/2));
-		ale_pos desired_h_angle = 2 * atan(h / (2 * sqrt(D*D + w*w/4)));
-		ale_pos desired_w_angle = 2 * atan(w / (2 * sqrt(D*D + h*h/4)));
+		ale_pos D = (ale_pos) sqrt(h * h + w * w)
+			         / (ale_pos) (2 * tan(_init_angle/2));
+		ale_pos desired_h_angle = (double) (2 * atan((double) ((double) h / (2 * sqrt((double) (D*D) + (double) (w*w)/4)))));
+		ale_pos desired_w_angle = (double) (2 * atan((double) ((double) w / (2 * sqrt((double) (D*D) + (double) (h*h)/4)))));
 
 		ale_pos estimate_h1_angle = estimate.anglebetw(a, b);
 		ale_pos estimate_h2_angle = estimate.anglebetw(c, d);
@@ -145,7 +145,7 @@ class align {
 		 * can be changed at each step.  
 		 */
 
-		double view_angle = _init_angle;
+		ale_pos view_angle = _init_angle;
 
 		for (ale_pos magnitude = estimate[2] / 2; 
 			magnitude >= 1;
@@ -183,10 +183,10 @@ class align {
 					
 				old_error = error;
 
-				for (double c0 = -magnitude; c0 <= magnitude; c0 += magnitude)
-				for (double c1 = -magnitude; c1 <= magnitude; c1 += magnitude) 
-				for (double c2 = -magnitude; c2 <= magnitude; c2 += magnitude) 
-				for (double c3 = -magnitude; c3 <= magnitude; c3 += magnitude) {
+				for (ale_pos c0 = -magnitude; c0 <= magnitude; c0 += magnitude)
+				for (ale_pos c1 = -magnitude; c1 <= magnitude; c1 += magnitude) 
+				for (ale_pos c2 = -magnitude; c2 <= magnitude; c2 += magnitude) 
+				for (ale_pos c3 = -magnitude; c3 <= magnitude; c3 += magnitude) {
 
 					if (c3 > 10)
 						c3 = 10;
@@ -198,10 +198,10 @@ class align {
 					estimate[2] += c2;
 					// view_angle += c3 / 30;
 
-					ale_pos D = sqrt(h * h + w * w)
-							 / (2 * tan(view_angle/2));
-					ale_pos desired_h_angle = 2 * atan(h / (2 * sqrt(D*D + w*w/4)));
-					ale_pos desired_w_angle = 2 * atan(w / (2 * sqrt(D*D + h*h/4)));
+					ale_pos D = (ale_pos) sqrt(h * h + w * w)
+							 / (ale_pos) (2 * tan(view_angle/2));
+					ale_pos desired_h_angle = 2 * atan((double) h / (2 * sqrt((double) (D*D) + (double) (w*w)/4)));
+					ale_pos desired_w_angle = 2 * atan((double) w / (2 * sqrt((double) D*D + (double) h*h/4)));
 
 					estimate_h1_angle = estimate.anglebetw(a, b);
 					estimate_h2_angle = estimate.anglebetw(c, d);
@@ -557,9 +557,9 @@ public:
 //				alignment_array[i](estimate)[2]);
 
 			ale_pos e0 = atan(-e_translated[1] / e_translated[2]);
-			ale_pos e1 = atan(e_translated[0]
-					/ (e_translated[2] * cos(e0)
-					 - e_translated[1] * sin(e0)));
+			ale_pos e1 = atan((double) e_translated[0]
+					/ ((double) e_translated[2] * cos(e0)
+					 - (double) e_translated[1] * sin(e0)));
 
 			alignment_array[i].modify_rotation(0, e0);
 			alignment_array[i].modify_rotation(1, e1);
