@@ -189,7 +189,7 @@ public:
 			"Tunable parameters:\n"
 			HEADER_SPACE
 			"--metric=x        Set the alignment error metric exponent.       (2 is default)\n"
-			"--threshold=x     Min. match threshold; a perfect match is 100.  (0 is default)\n"
+			"--threshold=x     Minimum match percentage; -1 disables check.  (-1 is default)\n"
 			"--perturb-upper=x Perturbation upper bound pixels/arclength    (14%% is default)\n"
 			"                     ('x%%' uses a fraction of the smallest image dimension.)\n"
 			"--perturb-lower=x Perturbation lower bound pixels/arclength   (.125 is default)\n"
@@ -197,7 +197,8 @@ public:
 			"--rot-upper=x     Rotation-specific upper bound in degrees    (32.0 is default)\n"
 			"--bda-mult=x      Barrel distortion adjustment multiplier      (2.0 is default)\n"
 			"--bda-rate=x      Barrel distortion rate of change maximum     (8.0 is default)\n"   
-			"--lod-max=x       LOD scale factor is max(1, (2^floor(x))/perturb)  (-4 is def)\n"
+			"--lod-preferred=x Preferred LOD scale is (2^floor(x))/perturb)  (-3 is default)\n"
+			"--min-dimension=x Minimum dimension for reduced LOD is x        (10 is default)\n"
 			"--mc <x>          Statically sample ~x%% of available pixels     (30 is default)\n"
 			BETWEEN_SECTIONS
 			"Certainty-weighted alignment:\n"
@@ -253,7 +254,14 @@ public:
 			BETWEEN_SECTIONS
 			"Multi-alignment:\n"
 			HEADER_SPACE
-			"--md <n>          Use no more than <n>-fold decomposition.       (3 is default)\n"
+			"--multi <type>    Set multi-alignment <type>, one of:\n"
+			"                     none      Single alignment only\n"
+			"                     local     Best local element\n"
+			"                     fill      Best local element followed by filling [default]\n"
+			"                     llocal    Least-size local element\n"
+			"                     global    Best element\n"
+			"--md <x>          Set element minimum dimension x.             (100 is default)\n"
+			"--ma-cert <x>     Set mean certainty lower bound.             (0.01 is default)\n" 
 			"\n"
 		       );
 	}
@@ -711,6 +719,10 @@ public:
 	void process() {
 		banner("Process details");
 		fprintf(help_stream,
+			BETWEEN_SECTIONS
+			"Memory:\n"
+			HEADER_SPACE
+			"--resident <x>    Max resident megapixels per array; 0 is unlimited (0 default)\n"
 			BETWEEN_SECTIONS
 			"Profiling:\n"
 			HEADER_SPACE
