@@ -43,6 +43,8 @@ const char *input::supported_nonglobal_option_table[] = {
 	"gs-mo",
 	"black",
 	"md",
+	"ma-cert",
+	"mi",
 	NULL
 };
 
@@ -106,6 +108,7 @@ input::simple_option input::simple_option_table[] = {
 	{ "mc", NULL, NULL, 1 },
 
 	{ "cache", NULL, NULL, 1 },
+	{ "resident", NULL, NULL, 1 },
 
 	{ "ev", NULL, NULL, 1 },
 	{ "black", NULL, NULL, 1 },
@@ -116,10 +119,14 @@ input::simple_option input::simple_option_table[] = {
 	{ "oc" }, 
 	{ "no-oc", "oc", "0" },
 
+	{ "multi", NULL, NULL, 1 },
+
 	{ "gs", NULL, NULL, 1 },
 	{ "gs-mo", NULL, NULL, 1 },
 
 	{ "md", NULL, NULL, 1 },
+	{ "ma-cert", NULL, NULL, 1 },
+	{ "mi", NULL, NULL, 1 },
 
 	{ "focus", "error" },
 
@@ -276,7 +283,8 @@ input::simple_option input::simple_option_table[] = {
 	{ "bda-mult", NULL, NULL, 1 },
 	{ "bda-rate", NULL, NULL, 1 },
 
-	{ "lod-max", NULL, NULL, 1 },
+	{ "lod-preferred", NULL, NULL, 1 },
+	{ "min-dimension", NULL, NULL, 1 },
 
 	{ "model-load", NULL, NULL, 1 },
 	{ "model-save", NULL, NULL, 1 },
